==> nivo-0.6.0.tgz: package/es/components/charts/pie/PieSliceLegends.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import invariant from 'invariant';
import _ from 'lodash-es';
import d3 from 'd3';
import Nivo from '../../../Nivo';
import { findNeighbor, midAngle, radiansToDegrees } from '../../../ArcUtils';
import { getColorStyleObject } from '../../../ColorUtils';

var PieSliceLegends = function (_Component) {
    _inherits(PieSliceLegends, _Component);

    function PieSliceLegends() {
        _classCallCheck(this, PieSliceLegends);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    PieSliceLegends.decoratePie = function decoratePie(element) {
        var props = element.props;


        var badgeColorStyle = getColorStyleObject(props.badgeColor, 'fill');
        var textColorStyle = getColorStyleObject(props.textColor, 'fill');

        return function (_ref) {
            var element = _ref.element,
                identity = _ref.identity,
                arc = _ref.arc,
                previousData = _ref.previousData,
                newData = _ref.newData;

            var legends = element.selectAll('.slice-legend').data(newData, identity);

            var labelFn = props.labelFn || identity;

            legends.enter().append('g').attr('class', 'slice-legend').attr('transform', function (d) {
                var centroid = arc.centroid(d);

                return 'translate(' + centroid[0] + ', ' + centroid[1] + ')';
            }).style('opacity', 0).each(function (d, i) {
                this._current = findNeighbor(i, identity, previousData, newData) || _.assign({}, d, { endAngle: d.startAngle });
                var el = d3.select(this);

                el.append('circle').attr('r', props.radius);

                el.append('text').attr('text-anchor', 'middle');
            });

            legends.each(function (d) {
                d3.select(this).select('circle').style(badgeColorStyle);

                d3.select(this).select('text').style(textColorStyle).text(labelFn(d));
            }).transition().duration(props.transitionDuration).ease(props.transitionEasing).style('opacity', 1).attrTween('transform', function (d) {
                var interpolate = d3.interpolate({
                    startAngle: this._current.startAngle,
                    endAngle: this._current.endAngle
                }, d);

                return function (t) {
                    var angles = interpolate(t);
                    var centroid = arc.centroid(angles);

                    var transform = 'translate(' + centroid[0] + ', ' + centroid[1] + ')';
                    if (props.orient) {
                        var angle = midAngle(angles);
                        transform = transform + ' rotate(' + radiansToDegrees(angle) + ', 0, 0)';
                    }

                    return transform;
                };
            });

            legends.exit().transition().duration(props.transitionDuration).ease(props.transitionEasing).style('opacity', 0).remove();
        };
    };

    PieSliceLegends.prototype.render = function render() {
        invariant(false, '<PieSliceLegends> element is for Pie configuration only and should not be rendered');
    };

    return PieSliceLegends;
}(Component);

var number = PropTypes.number,
    string = PropTypes.string,
    bool = PropTypes.bool,
    func = PropTypes.func,
    any = PropTypes.any;


PieSliceLegends.propTypes = {
    labelFn: func,
    radius: number.isRequired,
    orient: bool.isRequired,
    transitionDuration: number.isRequired,
    transitionEasing: string.isRequired,
    badgeColor: any.isRequired,
    textColor: any.isRequired
};

PieSliceLegends.defaultProps = {
    radius: 12,
    orient: true,
    transitionDuration: Nivo.defaults.transitionDuration,
    transitionEasing: Nivo.defaults.transitionEasing,
    badgeColor: 'none',
    textColor: 'none'
};

export default PieSliceLegends;

==> nivo-0.15.0.tgz: package/es/components/charts/pie/PieSliceLegends.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import invariant from 'invariant';
import _ from 'lodash-es';
import d3 from 'd3';
import Nivo from '../../../Nivo';
import { findNeighbor, midAngle, radiansToDegrees } from '../../../lib/arcUtils';
import { getColorStyleObject } from '../../../lib/colorUtils';

var PieSliceLegends = function (_Component) {
    _inherits(PieSliceLegends, _Component);

    function PieSliceLegends() {
        _classCallCheck(this, PieSliceLegends);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    PieSliceLegends.decoratePie = function decoratePie(element) {
        var props = element.props;


        var badgeColorStyle = getColorStyleObject(props.badgeColor, 'fill');
        var textColorStyle = getColorStyleObject(props.textColor, 'fill');

        return function (_ref) {
            var element = _ref.element,
                identity = _ref.identity,
                arc = _ref.arc,
                previousData = _ref.previousData,
                newData = _ref.newData;

            var legends = element.selectAll('.slice-legend').data(newData, identity);

            var labelFn = props.labelFn || identity;

            legends.enter().append('g').attr('class', 'slice-legend').attr('transform', function (d) {
                var centroid = arc.centroid(d);

                return 'translate(' + centroid[0] + ', ' + centroid[1] + ')';
            }).style('opacity', 0).each(function (d, i) {
                this._current = findNeighbor(i, identity, previousData, newData) || _.assign({}, d, { endAngle: d.startAngle });
                var el = d3.select(this);

                el.append('circle').attr('r', props.radius);

                el.append('text').attr('text-anchor', 'middle');
            });

            legends.each(function (d) {
                d3.select(this).select('circle').style(badgeColorStyle);

                d3.select(this).select('text').style(textColorStyle).text(labelFn(d));
            }).transition().duration(props.transitionDuration).ease(props.transitionEasing).style('opacity', 1).attrTween('transform', function (d) {
                var interpolate = d3.interpolate({
                    startAngle: this._current.startAngle,
                    endAngle: this._current.endAngle
                }, d);

                return function (t) {
                    var angles = interpolate(t);
                    var centroid = arc.centroid(angles);

                    var transform = 'translate(' + centroid[0] + ', ' + centroid[1] + ')';
                    if (props.orient) {
                        var angle = midAngle(angles);
                        transform = transform + ' rotate(' + radiansToDegrees(angle) + ', 0, 0)';
                    }

                    return transform;
                };
            });

            legends.exit().transition().duration(props.transitionDuration).ease(props.transitionEasing).style('opacity', 0).remove();
        };
    };

    PieSliceLegends.prototype.render = function render() {
        invariant(false, '<PieSliceLegends> element is for Pie configuration only and should not be rendered');
    };

    return PieSliceLegends;
}(Component);

var number = PropTypes.number,
    string = PropTypes.string,
    bool = PropTypes.bool,
    func = PropTypes.func,
    any = PropTypes.any;


PieSliceLegends.propTypes = {
    labelFn: func,
    radius: number.isRequired,
    orient: bool.isRequired,
    transitionDuration: number.isRequired,
    transitionEasing: string.isRequired,
    badgeColor: any.isRequired,
    textColor: any.isRequired
};

PieSliceLegends.defaultProps = {
    radius: 12,
    orient: true,
    transitionDuration: Nivo.defaults.transitionDuration,
    transitionEasing: Nivo.defaults.transitionEasing,
    badgeColor: 'none',
    textColor: 'none'
};

export default PieSliceLegends;
